
From: Eric Lammerts <eric@lammerts.org>

We know that the randomisation slows down some workloads on Transmeta CPUs
by quite large amounts.  We think it's because the CPU needs to recode the
same x86 instructions when they pop up at a different virtual address after
a fork+exec.

So disable randomization by default on those CPUs.

Signed-off-by: Andrew Morton <akpm@osdl.org>
---

 arch/i386/kernel/cpu/transmeta.c |    4 ++++
 1 files changed, 4 insertions(+)

diff -puN arch/i386/kernel/cpu/transmeta.c~disable-address-space-randomization-on-transmeta-cpus arch/i386/kernel/cpu/transmeta.c
--- devel/arch/i386/kernel/cpu/transmeta.c~disable-address-space-randomization-on-transmeta-cpus	2005-07-29 18:23:21.000000000 -0700
+++ devel-akpm/arch/i386/kernel/cpu/transmeta.c	2005-07-29 18:23:21.000000000 -0700
@@ -76,6 +76,10 @@ static void __init init_transmeta(struct
 #define USER686 (X86_FEATURE_TSC|X86_FEATURE_CX8|X86_FEATURE_CMOV)
         if ( c->x86 == 5 && (c->x86_capability[0] & USER686) == USER686 )
 		c->x86 = 6;
+
+	/* randomize_va_space slows us down enormously;
+	   it probably triggers retranslation of x86->native bytecode */
+	randomize_va_space = 0;
 }
 
 static void transmeta_identify(struct cpuinfo_x86 * c)
_
